@@ -149,7 +149,7 @@ instance Show (HashTable s k v) where
 
 ------------------------------------------------------------------------------
 -- | See the documentation for this function in
--- "Data.HashTable.Class#v:new".
+-- 'Data.HashTable.Class.new'.
 new :: ST s (HashTable s k v)
 new = newSizedReal 2 >>= newRef
 {-# INLINE new #-}
@@ -157,7 +157,7 @@ new = newSizedReal 2 >>= newRef
 
 ------------------------------------------------------------------------------
 -- | See the documentation for this function in
--- "Data.HashTable.Class#v:newSized".
+-- 'Data.HashTable.Class.newSized'.
 newSized :: Int -> ST s (HashTable s k v)
 newSized n = do
     let n' = (n + numElemsInCacheLine - 1) `div` numElemsInCacheLine
@@ -168,7 +168,7 @@ newSized n = do
 
 ------------------------------------------------------------------------------
 -- | See the documentation for this function in
--- "Data.HashTable.Class#v:insert".
+-- 'Data.HashTable.Class.insert'.
 insert :: (Eq k, Hashable k) => HashTable s k v -> k -> v -> ST s ()
 insert ht !k !v = readRef ht >>= \h -> insert' h k v >>= writeRef ht
 
@@ -199,7 +199,7 @@ mutateST htRef !k !f = do
 
 ------------------------------------------------------------------------------
 -- | See the documentation for this function in
--- "Data.HashTable.Class#v:computeOverhead".
+-- 'Data.HashTable.Class.computeOverhead'.
 computeOverhead :: HashTable s k v -> ST s Double
 computeOverhead htRef = readRef htRef >>= work
   where
@@ -222,7 +222,7 @@ computeOverhead htRef = readRef htRef >>= work
 
 ------------------------------------------------------------------------------
 -- | See the documentation for this function in
--- "Data.HashTable.Class#v:delete".
+-- 'Data.HashTable.Class.delete'.
 delete :: (Hashable k, Eq k) =>
           HashTable s k v
        -> k
@@ -243,7 +243,7 @@ delete htRef k = readRef htRef >>= go
 
 ------------------------------------------------------------------------------
 -- | See the documentation for this function in
--- "Data.HashTable.Class#v:lookup".
+-- 'Data.HashTable.Class.lookup'.
 lookup :: (Eq k, Hashable k) =>
           HashTable s k v
        -> k
@@ -321,7 +321,7 @@ searchOne !keys !hashes !k !b0 !h = go b0
 
 ------------------------------------------------------------------------------
 -- | See the documentation for this function in
--- "Data.HashTable.Class#v:foldM".
+-- 'Data.HashTable.Class.foldM'.
 foldM :: (a -> (k,v) -> ST s a)
       -> a
       -> HashTable s k v
@@ -356,7 +356,7 @@ foldMWork f seed0 (HashTable sz _ hashes keys values _) = go 0 seed0
 
 ------------------------------------------------------------------------------
 -- | See the documentation for this function in
--- "Data.HashTable.Class#v:mapM_".
+-- 'Data.HashTable.Class.mapM_'.
 mapM_ :: ((k,v) -> ST s a)
       -> HashTable s k v
       -> ST s ()
@@ -432,14 +432,14 @@ mutate' :: (Eq k, Hashable k) =>
         -> (Maybe v -> ST s (Maybe v, a))
         -> ST s (HashTable_ s k v, a)
 mutate' ht@(HashTable sz _ hashes keys values _) !k !f = do
-    !(maybeVal, idx, hashCode) <- lookupSlot
+    !(maybeVal, idx, _hashCode) <- lookupSlot
     !fRes <- f maybeVal
     case (maybeVal, fRes) of
         (Nothing, (Nothing, a)) -> return (ht, a)
-        (Just v, (Just v', a)) -> do
+        (Just _v, (Just v', a)) -> do
             writeArray values idx v'
             return (ht, a)
-        (Just v, (Nothing, a)) -> do
+        (Just _v, (Nothing, a)) -> do
             deleteFromSlot ht idx
             return (ht, a)
         (Nothing, (Just v', a)) -> do
@@ -486,7 +486,7 @@ mutate' ht@(HashTable sz _ hashes keys values _) !k !f = do
               else do
                 result <- cuckooOrFail ht h1 h2 b1 b2 k v
                 maybe (return ht)
-                      (\(k', v') -> do
+                      (\(_k', _v') -> do
                           newHt <- grow ht k v
                           return newHt)
                       result
@@ -498,7 +498,7 @@ deleteFromSlot :: (Eq k, Hashable k) =>
                   HashTable_ s k v
                -> Int
                -> ST s ()
-deleteFromSlot ht@(HashTable _ _ hashes keys values _) idx = do
+deleteFromSlot _ht@(HashTable _ _ hashes keys values _) idx = do
     U.writeArray hashes idx emptyMarker
     writeArray keys idx undefined
     writeArray values idx undefined
@@ -513,7 +513,7 @@ insertIntoSlot :: (Eq k, Hashable k) =>
                -> k
                -> v
                -> ST s ()
-insertIntoSlot ht@(HashTable _ _ hashes keys values _) idx he k v = do
+insertIntoSlot _ht@(HashTable _ _ hashes keys values _) idx he k v = do
     U.writeArray hashes idx he
     writeArray keys idx k
     writeArray values idx v
